@@ -8,7 +8,9 @@ import unittest
 import tempfile
 import json
 
+from mock import patch
 from DistUpgrade.DistUpgradeQuirks import DistUpgradeQuirks
+from DistUpgrade.RiscvProfile import RiscvProfile
 
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -543,6 +545,43 @@ max_framebuffers=2
 
         popen_mock.assert_not_called()
 
+    def test_test_and_fail_on_rva23(self):
+        """
+        Unit test for DistUpgradeQuirks.test_and_fail_on_rva23
+
+        Expect abort for system not complying with RVA23U64.
+        Expect no abort for compliant sytem.
+        """
+
+        # All RVA23U64 mandatory extensions
+        good_cpu_info = RiscvProfile(
+               'rv64imafdcbv_zic64b_zicbom_zicbop_zicboz_ziccamoa_ziccif_'
+               'zicclsm_ziccrse_zicntr_zicond_zicsr_zihintntl_'
+               'zihintpause_zihpm_zimop_za64rs_zawrs_zfa_zfhmin_zcb_'
+               'zcmop_zvbb_zvfhmin_zvkt_zkt_supm')
+
+        # Vector support missing
+        bad_cpu_info = RiscvProfile(
+               'rv64imafdcb_zic64b_zicbom_zicbop_zicboz_ziccamoa_ziccif_'
+               'zicclsm_ziccrse_zicntr_zicond_zicsr_zihintntl_'
+               'zihintpause_zihpm_zimop_za64rs_zawrs_zfa_zfhmin_zcb_'
+               'zcmop_zkt_supm')
+
+        mock_controller = mock.Mock()
+        q = DistUpgradeQuirks(mock_controller, mock.Mock())
+
+        with patch.object(RiscvProfile,
+                          'read_cpuinfo') as mock_cpuinfo:
+            mock_cpuinfo.return_value = good_cpu_info
+            q._test_and_fail_on_rva23()
+            self.assertEqual(0, len(mock_controller.abort.mock_calls))
+
+        with patch.object(RiscvProfile,
+                          'read_cpuinfo') as mock_cpuinfo:
+            mock_cpuinfo.return_value = bad_cpu_info
+            q._test_and_fail_on_rva23()
+            self.assertEqual(1, len(mock_controller.abort.mock_calls))
+
 
 class TestSnapQuirks(unittest.TestCase):
 
